function [var_n,var_x]=noise_floor_estimate(x)

% x: signal to be processed

xds=resample(x,100,3675,20);
fsd=1200;
p1=200;
p2=60;
[vad]=vad_nfe(xds,fsd,p1,p2);
vad=resample(double(vad),3675,100,0); 
vad=vad(1:length(x));  % vad na taxa original
%plot(x); hold on; plot(.1*vad,'r'); pause; close
var_n=var(x(logical(~vad)));
var_x=var(x(logical(vad)))-var_n;

%snr=10*log10(var_x/var_n);


function  [vad]=vad_nfe(x,fs,p1,p2)

% INPUTS
% x: input signal (column vector)
% fs: sampling frequency
% p1: minimum mute interval (respiration interval) in ms 
% p2: minimum voice active interval in ms

% typical values: p1=200 to 250 and p2=50

% OUTPUTS:
% vad: binary indicator vector. vad=1 implies sample related to voice
% activity
% ind0: set of indices related to the mute intervals. Ex. first mute
% interval ranges from ind0(1) to ind0(2) whereas the second mute interval
% ranges from ind0(3) to ind0(4)

% ind1: set of indices related to the mute intervals. Ex. first vad
% interval ranges from ind1(1) to ind1(2) whereas the second mute interval
% ranges from ind1(3) to ind1(4)


phoneme_int=25; % mean phoneme interval in ms 
win_phoneme=round(phoneme_int*fs/1000);  % mean mute interval in samples 
win1=round(win_phoneme/3);

mx=(abs(x));
energy_profile=ordfilt2(mx,round(win1/2),ones(win1,1)); % applies median filter



clear mx

mep=median(energy_profile); % median of energy _profile
[cc,thr_min] = hist(energy_profile,150); % histogram of energy_profile
%plot(thr_min,cc); %  
[vv,inddd] = max(cc); % finds maximum of the histogram count
thr_min=thr_min(inddd+2); % sets minimum threshold as one bin above that of the maximum
% the above measure is taken to avoid a too low thr when a large portion of
% the signal is of background noise.

%thr=1.5*mep;
thr=max(3*mep,thr_min);

energy_profile=mep+energy_profile; % lifts energy_profile by its mean
energy_profile=ordfilt2(energy_profile,win_phoneme,ones(win_phoneme,1)); % applies maximum filter

% energy_profile=ordfilt2(energy_profile,win_phoneme,ones(win_phoneme,1)); % applies maximum filter
% mep=median(energy_profile);
% thr=1.5*mep;
% energy_profile=mep+energy_profile; % lifts energy_profile by its mean

mute_int=p1; % minimum mute interval (in ms)
win_mute=round(mute_int*fs/1000);  % minimum mute interval in samples 
speech_persistence=p2; % in ms
win_sp=round(speech_persistence*fs/1000);  % minimum voice activity interval in samples 

%plot(x); hold on; plot(energy_profile,'r'); plot(thr*ones(size(energy_profile)),'k'); pause; close

vad=energy_profile>thr; % compares energy_profile with thr to generate the initial VAD  
clear energy_profile

% post processing:
% 1) to remove short-duration VAD bursts 
% 1) to merge short gaps in VAD

%plot(x); hold on; plot(vad,'r'); pause

[vad,ind1,ind0]=vad_short_zero_value_gap_removal_v1(~vad,win_sp); % short bursts remvoval

[vad,ind0,ind1]=vad_short_zero_value_gap_removal_v1(~vad,win_mute); % merging of short mutes
