function fig1
% Generates figure 1 of the paper 
% Paulo Esquef: 02 April 2015
clear all; close all; clc
addpath('..\common')
% Loads coefficients of the filter parameters
load filter_60Hz_1p4Hz_4th  % loads filter coeff. a and b (elliptic bandpass centered at 60 Hz)
load filter_PB20_20Hz_5th % b20 a20 (elliptic lowpass filter with 20Hz passband and zero at 60 Hz)

br=1000;  % number of samples to be discarded in the beginning and end of the processed signal due to filter transients
fs=16000; % sample rate (this matches the sample rate of signals of the Spanish Database)
n=(0:1/fs:6)'; % temporal basis (6 s)
f0=50; % Nominal frequency of the ideal ENF (in Hz)  
x=0.01*cos(2*pi*f0*n); % generates an ideal ENF component
N50=fs/50; % number of samples of one 50 Hz cycle at fs
cut_point=round(length(x)/2); % cut position in the middle of the signal 

cut_fraction=.1;
[dp1]=gen_template(x,cut_fraction,cut_point,N50,br);
cut_fraction=.2;
[dp2]=gen_template(x,cut_fraction,cut_point,N50,br);
cut_fraction=.3;
[dp3]=gen_template(x,cut_fraction,cut_point,N50,br);
cut_fraction=.4;
[dp4]=gen_template(x,cut_fraction,cut_point,N50,br);
cut_fraction=.5;
[dp5]=gen_template(x,cut_fraction,cut_point,N50,br);




% cut_range=cut_point-1+(1:round(cut_fraction*N50)); % defines cut range
% x(cut_range)=[]; % implements cut 
% % x now is the test signal
% % Run now steps 1 to 5
% xds=resample(x,1,16,20); % downsampling from 16 kHz to 1000 Hz  
% fsd=1000;   % new sampling rate
% xds_f=filtfilt(b,a,xds); % bandpass filters (around 50Hz) the downsampled signal 
% z=hilbert(xds_f);  % calculates the analytic signal associated with xds_f
% f=phase(z(2:end,:).*conj(z(1:end-1,:)));  % Hilbert estimate of the instantaneous frequency of xds_f  
% d=f-median(f(br:end-br));  % removes median value from the instananeous frequency of xds_f 
% d=filtfilt(b20,a20,d); % lowpass filters f (20Hz passband) to remove the 60 Hz oscillations that leaks into the Hilbert estimate
% d=abs(d(br:end-br)); % removes transitory effects

screen_size = [414   250   755   731];
%get(0, 'ScreenSize');
figure(1)
set(gcf, 'Position', [0 0 screen_size(3) screen_size(4) ] ); % plots full screen
subplot(211)
plot(dp1,'linewidth',2,'color',.85*[1 1 1]);   % plots dp1 (template related to cut of 0.1 of a 50 Hz cycle) 
hold on
plot(dp2,'-r','linewidth',2,'color',.65*[1 1 1]);   % idem dp2
plot(dp3,'-m','linewidth',2,'color',.45*[1 1 1]);   % idem dp3 
plot(dp4,'-y','linewidth',2,'color',.25*[1 1 1]);   % idem dp4 
%plot(dp5,'-k','linewidth',2);   % idem dp5 
set(gca,'fontsize',16)
ylabel('$d_0[n]$','interpreter','latex','fontsize',18)
axis tight
aa=axis;
axis([aa(1) aa(2) aa(3)-0.0002 aa(4)])
legend('0.1','0.2','0.3','0.4')
text(150,14e-3,'(a)','fontsize',16)

subplot(212)
plot(dp5,'-k','linewidth',2);   % idem dp5 
set(gca,'fontsize',16)
xlabel('$n$','interpreter','latex','fontsize',18)
ylabel('$d_0[n]$','interpreter','latex','fontsize',18)
axis tight
aa=axis;
axis([aa(1) aa(2) aa(3)-0.001 aa(4)])
legend('0.5')
text(150,.08,'(b)','fontsize',16)







function [d]=gen_template(x,cut_fraction,cut_point,N50,br)
addpath('..\common')
load filter_60Hz_1p4Hz_4th  % loads filter coeff. a and b (elliptic bandpass centered at 60 Hz)
load filter_PB20_20Hz_5th % b20 a20 (elliptic lowpass filter with 20Hz passband and zero at 60 Hz)
% x is the input signal to be cut and processed
% cut_fraction is the percentage of the 50Hz cycle to be cut out of the
% signal
% cut_point is the sample index of the beginning of the cut 
cut_range=cut_point-1+(1:round(cut_fraction*N50)); % defines cut range
x(cut_range)=[]; % implements cut 
% Run now steps 1 to 5
xds=resample(x,1,16,20); % downsampling from 16 kHz to 1000 Hz  
fsd=1000;   % new sampling rate
xds_f=filtfilt(b,a,xds); % bandpass filters (around 50Hz) the downsampled signal 
z=hilbert(xds_f);  % calculates the analytic signal associated with xds_f
f=phase(z(2:end,:).*conj(z(1:end-1,:)));  % Hilbert estimate of the instantaneous frequency of xds_f  
d=f-median(f(br:end-br));  % removes median value from the instananeous frequency of xds_f 
d=filtfilt(b20,a20,d); % lowpass filters f (20Hz passband) to remove the 60 Hz oscillations that leaks into the Hilbert estimate
d=abs(d(br:end-br)); % removes transitory effects
