% Generates figure 2 of the paper 
% Paulo Esquef: 02 April 2015
clear all; close all; clc
addpath('..\common')
% Loads coefficients of the filter parameters
load filter_60Hz_1p4Hz_4th  % loads filter coeff. a and b (elliptic bandpass centered at 60 Hz)
load filter_PB20_20Hz_5th % b20 a20 (elliptic lowpass filter with 20Hz passband and zero at 60 Hz)

br=1500;  % number of samples to be discarded in the beginning and end of the processed signal due to filter transients
fs=16000; % sample rate (this matches the sample rate of signals of the Spanish Database)
n=(0:1/fs:7)'; % temporal basis (6 s)
f0=50; % Nominal frequency of the ideal ENF (in Hz)  
x=0.01*cos(2*pi*f0*n); % generates an ideal ENF component
noise_burst_point=round(length(x)/2); % position of an artificial impulsive noise in the middle of the signal 

%x(noise_burst_point+(1:150))=x(noise_burst_point+(1:150))+.01*randn(150,1); % add a click in the middle of the signal
xds=resample(x,1,16,20); % downsampling from 16 kHz to 1000 Hz  
fsd=1000;   % new sampling rate
xds_f=filtfilt(b,a,xds); % bandpass filters (around 50Hz) the downsampled signal 
z=hilbert(xds_f);  % calculates the analytic signal associated with xds_f
f=phase(z(2:end,:).*conj(z(1:end-1,:)));  % Hilbert estimate of the instantaneous frequency of xds_f  
d=f-median(f(br:end-br));  % removes median value from the instananeous frequency of xds_f 
d=filtfilt(b20,a20,d); % lowpass filters f (20Hz passband) to remove the 60 Hz oscillations that leaks into the Hilbert estimate
d=abs(d(br:end-br)); % removes transitory effects
dclean=d;
clear d

load noise_burst
%noise_burst=.03*randn(150,1);
x(noise_burst_point+(1:150))=x(noise_burst_point+(1:150))+noise_burst; % add a click in the middle of the signal
xds=resample(x,1,16,20); % downsampling from 16 kHz to 1000 Hz  
fsd=1000;   % new sampling rate
xds_f=filtfilt(b,a,xds); % bandpass filters (around 50Hz) the downsampled signal 
z=hilbert(xds_f);  % calculates the analytic signal associated with xds_f
f=phase(z(2:end,:).*conj(z(1:end-1,:)));  % Hilbert estimate of the instantaneous frequency of xds_f  
d=f-median(f(br:end-br));  % removes median value from the instananeous frequency of xds_f 
d=filtfilt(b20,a20,d); % lowpass filters f (20Hz passband) to remove the 60 Hz oscillations that leaks into the Hilbert estimate
d=abs(d(br:end-br)); % removes transitory effects
dburst=d;

figure(1)
%set(gcf, 'Position', [0 0 screen_size(3) screen_size(4) ] ); % plots full screen
plot(dclean,'linewidth',2,'color',.75*[1 1 1]);   % plots dp1 (template related to cut of 0.1 of a 50 Hz cycle) 
hold on
plot(dburst,'linewidth',2,'color',.05*[1 1 1]);   % plots dp1 (template related to cut of 0.1 of a 50 Hz cycle) 
set(gca,'fontsize',13)
ylabel('$d[n]$','interpreter','latex','fontsize',16)
xlabel('$n$','interpreter','latex','fontsize',16')
axis tight
aa=axis;
axis([aa(1) aa(2) aa(3)-2e-7 aa(4)+2e-7])
legend('clean','noise burst')


